﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoMapper;
using AutoMapperDemo.Dtos;
using AutoMapperDemo.Models;
using Xunit;

namespace AutoMapperDemo;

public class Demo
{
    private readonly IMapper _mapper = new Mapper(new MapperConfiguration(expression => expression.AddProfile<MappingProfile>()));

    private Vehicle _tatra813;
    private Vehicle _fordGalaxy;
    private Manufacturer _tatraComp;
    private Manufacturer _fordComp;
    private IList<Vehicle> _allVehicles;
    private IList<Manufacturer> _allManufacturers;

    public Demo()
    {
        _tatra813 = new Vehicle
        {
            Id = Guid.NewGuid(),
            Name = "Tatra 813",
            LicensePlate = "9BK7459",
            DrivenKilometers = 825_000,
            Type = "Truck",
            WheelsCount = 10,
            YearOfManufacture = 2000,
            AdditionalInfo = "Famous military truck"
        };
        _fordGalaxy = new Vehicle
        {
            Id = Guid.NewGuid(),
            Name = "Ford Galaxy",
            LicensePlate = "4SN1234",
            DrivenKilometers = 4,
            Type = "Personal",
            WheelsCount = 4,
            YearOfManufacture = 2018,
            AdditionalInfo = "Big family car"
        };

        _tatraComp = new Manufacturer
        {
            Id = Guid.NewGuid(),
            YearOfEstablishment = 1850,
            Name = "Tatra company"
        };

        _fordComp = new Manufacturer
        {
            Id = Guid.NewGuid(),
            YearOfEstablishment = 1903,
            Name = "Ford company"
        };

        _allVehicles = new List<Vehicle>
        {
            _tatra813, _fordGalaxy
        };

        _allManufacturers = new List<Manufacturer>
        {
            _fordComp, _tatraComp
        };
    }

    public void Run()
    {
        // Mapping model -> dto
        var tatra813Dto = _mapper.Map<VehicleDto>(_tatra813);
        var fordCompanyDto = _mapper.Map<ManufacturerDto>(_fordComp);

        // Mapping model list -> dtos
        var vehiclesDtos = _mapper.Map<IList<VehicleDto>>(_allVehicles);
        var manufacturersDtos = _mapper.Map<IList<Manufacturer>>(_allManufacturers);

   
        // Model != DTO
        // because some properties ignored during mapping (see configuration .Ignore() )
        // because special mapping rule applied to properties (see configuration .ForMember() )
        Assert.NotEqual(_tatra813.AdditionalInfo, tatra813Dto.AdditionalInfo);
        Assert.NotEqual(_tatra813.LicensePlate, tatra813Dto.LicensePlate);
        Assert.Null(tatra813Dto.AdditionalInfo);
        Assert.Equal(_tatra813.LicensePlate, tatra813Dto.LicensePlate, true); // Ignore casing

        // Mapping back dto -> model
        var tatra813Reverse = _mapper.Map<Vehicle>(tatra813Dto);
    }
}