﻿using AutoMapper;
using AutoMapperDemo.Dtos;
using AutoMapperDemo.Models;

namespace AutoMapperDemo;

public class MappingProfile : Profile
{
    public MappingProfile()
    {
        // --------- Reverse mapping ---------
        CreateMap<Vehicle, VehicleDto>();
        CreateMap<VehicleDto, Vehicle>();
        CreateMap<Manufacturer, ManufacturerDto>();
        CreateMap<ManufacturerDto, Manufacturer>();

        // Equivalent of above
        CreateMap<VehicleDto, Vehicle>() 
            .ReverseMap();
        CreateMap<Manufacturer, ManufacturerDto>() 
            .ReverseMap();

        // --------- Special mapping for members ---------
        CreateMap<Vehicle, VehicleDto>()
            .ForMember(dest => dest.LicensePlate, cfg => cfg.MapFrom(src => src.LicensePlate.ToLower()))
            .ForMember(dest => dest.AdditionalInfo, cfg => cfg.Ignore());

        CreateMap<Manufacturer, ManufacturerDto>()
            .ForMember(dest => dest.YearOfEstablishment, cfg => cfg.MapFrom(src => new DateTime(src.YearOfEstablishment, 1, 1)));
        CreateMap<ManufacturerDto, Manufacturer>()
            .ForMember(dest => dest.YearOfEstablishment, cfg => cfg.MapFrom(src => src.YearOfEstablishment.Year));

        // --------- Configuration for collections are automatically created ---------
        //CreateMap<IEnumerable<Vehicle>, IEnumerable<VehicleDto>>()

        // --------- Specific action after mapping ---------
        CreateMap<VehicleDto, Vehicle>()
            .AfterMap((dto, vehicle) => {});

        // --------- Specific action after mapping ---------
        CreateMap<VehicleDto, Vehicle>()
            .BeforeMap((dto, vehicle) => { });
    }
}