﻿using System.Reflection;
using Autofac;
using AutoMapper;
using ZooInfrastructure;
using Module = Autofac.Module;

namespace ZooBL.Configs;

public class AutofacBLConfig : Module
{
    protected override void Load(ContainerBuilder builder)
    {
        builder.RegisterModule(new AutofacInfrastructureConfig());

        builder.RegisterAssemblyTypes(Assembly.GetExecutingAssembly())
            .Where(t => t.Namespace == "ZooBL.QueryObjects")
            .InstancePerDependency();

        builder.RegisterAssemblyTypes(Assembly.GetExecutingAssembly())
            .Where(t => t.Namespace == "ZooBL.Services")
            .As(t => t.GetInterfaces().FirstOrDefault(i => i.Name == "I" + t.Name)!)
            .InstancePerDependency();

        builder.RegisterInstance(new Mapper(new MapperConfiguration(BusinessMappingConfig.ConfigureMapping)))
            .As<IMapper>()
            .SingleInstance();
    }

    public static IContainer Configure()
    {
        var builder = new ContainerBuilder();

        builder.RegisterModule(new AutofacInfrastructureConfig());

        builder.RegisterAssemblyTypes(Assembly.GetExecutingAssembly())
            .Where(t => t.Namespace == "ZooBL.QueryObjects")
            .AsSelf()
            .InstancePerDependency();

        builder.RegisterAssemblyTypes(Assembly.GetExecutingAssembly())
            .Where(t => t.Namespace == "ZooBL.Services")
            .As(t => t.GetInterfaces().FirstOrDefault(i => i.Name == "I" + t.Name)!)
            .InstancePerDependency();

        builder.RegisterInstance(new Mapper(new MapperConfiguration(BusinessMappingConfig.ConfigureMapping)))
            .As<IMapper>()
            .SingleInstance();

        return builder.Build();
    }
}