﻿using AutoMapper;
using ZooBL.Dto.Animal;
using ZooDAL.Models;
using ZooInfrastructure;

namespace ZooBL.Services;

public class AnimalService : IAnimalService
{
    private readonly IMapper _mapper;
    private readonly IUnitOfWork _unitOfWork;

    public AnimalService(IUnitOfWork unitOfWork, IMapper mapper)
    {
        _unitOfWork = unitOfWork;
        _mapper = mapper;
    }

    public async Task<AnimalDto?> GetAnimalByIdAsync(Guid animalId)
    {
        var animal = await _unitOfWork.AnimalRepository.GetAsync(animalId);

        return _mapper.Map<AnimalDto?>(animal);
    }

    public async Task<AnimalDto?> GetAnimalDetailByIdAsync(Guid animalId)
    {
        var animal = await _unitOfWork.AnimalRepository.GetAsync(animalId, nameof(Animal.Enclosure));

        return _mapper.Map<AnimalDto?>(animal);
    }

    public async Task UpdateAnimalAsync(Guid animalId, AnimalDto animalDto)
    {
        var updatedAnimal = _mapper.Map<Animal>(animalDto);
        _unitOfWork.AnimalRepository.Update(updatedAnimal);

        await _unitOfWork.CommitAsync();
    }

    public async Task DeleteAnimalAsync(Guid animalId)
    {
        await _unitOfWork.AnimalRepository.DeleteAsync(animalId);
        await _unitOfWork.CommitAsync();
    }

    public async Task<IEnumerable<AnimalDto>> GetAllAnimalsAsync()
    {
        var animals = await _unitOfWork.AnimalRepository.GetAllAsync();
        return _mapper.Map<IEnumerable<AnimalDto>>(animals);
    }

    public async Task CreateAnimalAsync(AnimalDto animalDto)
    {
        var animal = _mapper.Map<Animal>(animalDto);
        _unitOfWork.AnimalRepository.Create(animal);
        await _unitOfWork.CommitAsync();
    }
}