﻿using AutoMapper;
using ZooBL.Dto.Enclosure;
using ZooDAL.Models;
using ZooInfrastructure;

namespace ZooBL.Services;

public class EnclosureService : IEnclosureService
{
    private readonly IMapper _mapper;
    private readonly IUnitOfWork _unitOfWork;

    public EnclosureService(IUnitOfWork unitOfWork, IMapper mapper)
    {
        _unitOfWork = unitOfWork;
        _mapper = mapper;
    }

    public async Task AddAnimalToEnclosureAsync(Guid enclosureId, Guid animalId)
    {
        var enclosure = await _unitOfWork.EnclosureRepository.GetAsync(enclosureId, nameof(Enclosure.Animals));
        var animal = await _unitOfWork.AnimalRepository.GetAsync(animalId);

        enclosure.Animals.Add(animal);

        _unitOfWork.EnclosureRepository.Update(enclosure);

        await _unitOfWork.CommitAsync();
    }

    public async Task<EnclosureDto?> GetEnclosureByIdAsync(Guid enclosureId)
    {
        var enclosure = await _unitOfWork.EnclosureRepository.GetAsync(enclosureId);

        return _mapper.Map<EnclosureDto?>(enclosure);
    }

    public async Task<EnclosureWithAnimalsDto?> GetEnclosureDetailByIdAsync(Guid enclosureId)
    {
        var enclosure = await _unitOfWork.EnclosureRepository.GetAsync(enclosureId, nameof(Enclosure.Animals));

        return _mapper.Map<EnclosureWithAnimalsDto?>(enclosure);
    }

    public async Task UpdateEnclosureAsync(Guid enclosureId, EnclosureDto enclosureDto)
    {
        var updatedEnclosure = _mapper.Map<Enclosure>(enclosureDto);
        _unitOfWork.EnclosureRepository.Update(updatedEnclosure);

        await _unitOfWork.CommitAsync();
    }

    public async Task DeleteEnclosureAsync(Guid enclosureId)
    {
        await _unitOfWork.EnclosureRepository.DeleteAsync(enclosureId);
        await _unitOfWork.CommitAsync();
    }

    public async Task<IEnumerable<EnclosureDto>> GetAllEnclosuresAsync()
    {
        var enclosures = await _unitOfWork.EnclosureRepository.GetAllAsync();
        return _mapper.Map<IEnumerable<EnclosureDto>>(enclosures);
    }

    public async Task CreateEnclosureAsync(EnclosureDto enclosureDto)
    {
        var enclosure = _mapper.Map<Enclosure>(enclosureDto);
        _unitOfWork.EnclosureRepository.Create(enclosure);
        await _unitOfWork.CommitAsync();
    }
}