﻿using System;
using Microsoft.EntityFrameworkCore;
using ZooDAL.Models;

namespace ZooDAL.Data;

public static class DataInitializer
{
    public static readonly Guid EnclosureSuricataId = Guid.Parse("96cdec03-412d-447c-93f7-500ff78b3468");
    public static readonly Guid EnclosureTigerId = Guid.Parse("3a7dcd97-fc9b-4f65-bb72-7ed39ce6986c");

    public static readonly Guid SuricataTomId = Guid.Parse("01730e6c-0eb9-4468-a495-b1a66383ad71");
    public static readonly Guid SuricataJardaId = Guid.Parse("8a61ac97-9190-48ae-a9ce-83da2af0b0f0");
    public static readonly Guid TigerJackId = Guid.Parse("2e78135a-f135-47c8-884f-0998b16ddb21");

    public static void Seed(this ModelBuilder modelBuilder)
    {
        modelBuilder.Entity<Enclosure>().HasData(
            new Enclosure
            {
                Id = EnclosureSuricataId,
                Width = 8,
                Length = 8
            },
            new Enclosure
            {
                Id = EnclosureTigerId,
                Width = 16,
                Length = 24
            }
        );

        modelBuilder.Entity<Animal>().HasData
        (
            new Animal
            {
                Id = SuricataTomId,
                Name = "Tom",
                EnclosureId = EnclosureSuricataId,
                Age = 5,
                Specie = "Suricata",
                Weight = 720
            },
            new Animal
            {
                Id = SuricataJardaId,
                Name = "Jarda",
                EnclosureId = EnclosureSuricataId,
                Age = 4,
                Specie = "Suricata",
                Weight = 650
            },
            new Animal
            {
                Id = TigerJackId,
                Name = "Jack",
                EnclosureId = EnclosureTigerId,
                Age = 8,
                Specie = "Tiger",
                Weight = 300_000
            }
        );
    }
}