﻿using System;
using Microsoft.EntityFrameworkCore.Migrations;

#nullable disable

namespace ZooDAL.Migrations
{
    public partial class Initial : Migration
    {
        protected override void Up(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.CreateTable(
                name: "Adopters",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    FirstName = table.Column<string>(type: "nvarchar(64)", maxLength: 64, nullable: false),
                    Surname = table.Column<string>(type: "nvarchar(64)", maxLength: 64, nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Adopters", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "Enclosures",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    Width = table.Column<int>(type: "int", nullable: false),
                    Length = table.Column<int>(type: "int", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Enclosures", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "Animals",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    Name = table.Column<string>(type: "nvarchar(64)", maxLength: 64, nullable: false),
                    Specie = table.Column<string>(type: "nvarchar(max)", nullable: false),
                    Weight = table.Column<int>(type: "int", nullable: true),
                    Age = table.Column<int>(type: "int", nullable: true),
                    EnclosureId = table.Column<Guid>(type: "uniqueidentifier", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Animals", x => x.Id);
                    table.ForeignKey(
                        name: "FK_Animals_Enclosures_EnclosureId",
                        column: x => x.EnclosureId,
                        principalTable: "Enclosures",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "Adoptions",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    AdapterId = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    AnimalId = table.Column<Guid>(type: "uniqueidentifier", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Adoptions", x => x.Id);
                    table.ForeignKey(
                        name: "FK_Adoptions_Adopters_AdapterId",
                        column: x => x.AdapterId,
                        principalTable: "Adopters",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                    table.ForeignKey(
                        name: "FK_Adoptions_Animals_AnimalId",
                        column: x => x.AnimalId,
                        principalTable: "Animals",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.InsertData(
                table: "Enclosures",
                columns: new[] { "Id", "Length", "Width" },
                values: new object[] { new Guid("3a7dcd97-fc9b-4f65-bb72-7ed39ce6986c"), 24, 16 });

            migrationBuilder.InsertData(
                table: "Enclosures",
                columns: new[] { "Id", "Length", "Width" },
                values: new object[] { new Guid("96cdec03-412d-447c-93f7-500ff78b3468"), 8, 8 });

            migrationBuilder.InsertData(
                table: "Animals",
                columns: new[] { "Id", "Age", "EnclosureId", "Name", "Specie", "Weight" },
                values: new object[] { new Guid("01730e6c-0eb9-4468-a495-b1a66383ad71"), 5, new Guid("96cdec03-412d-447c-93f7-500ff78b3468"), "Tom", "Suricata", 720 });

            migrationBuilder.InsertData(
                table: "Animals",
                columns: new[] { "Id", "Age", "EnclosureId", "Name", "Specie", "Weight" },
                values: new object[] { new Guid("2e78135a-f135-47c8-884f-0998b16ddb21"), 8, new Guid("3a7dcd97-fc9b-4f65-bb72-7ed39ce6986c"), "Jack", "Tiger", 300000 });

            migrationBuilder.InsertData(
                table: "Animals",
                columns: new[] { "Id", "Age", "EnclosureId", "Name", "Specie", "Weight" },
                values: new object[] { new Guid("8a61ac97-9190-48ae-a9ce-83da2af0b0f0"), 4, new Guid("96cdec03-412d-447c-93f7-500ff78b3468"), "Jarda", "Suricata", 650 });

            migrationBuilder.CreateIndex(
                name: "IX_Adoptions_AdapterId",
                table: "Adoptions",
                column: "AdapterId");

            migrationBuilder.CreateIndex(
                name: "IX_Adoptions_AnimalId",
                table: "Adoptions",
                column: "AnimalId");

            migrationBuilder.CreateIndex(
                name: "IX_Animals_EnclosureId",
                table: "Animals",
                column: "EnclosureId");
        }

        protected override void Down(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.DropTable(
                name: "Adoptions");

            migrationBuilder.DropTable(
                name: "Adopters");

            migrationBuilder.DropTable(
                name: "Animals");

            migrationBuilder.DropTable(
                name: "Enclosures");
        }
    }
}
