﻿using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using Castle.Core.Internal;
using Microsoft.EntityFrameworkCore;
using ZooDAL;
using ZooDAL.Models;

namespace ZooInfrastructure;

public class Repository<TEntity> : IRepository<TEntity> where TEntity : BaseEntity
{
    private readonly ZooContext _dbContext;

    public Repository(ZooContext dbContext)
    {
        _dbContext = dbContext;
    }

    public async Task<TEntity?> GetAsync(Guid entityId, params string[] includes)
    {
        var queryable = _dbContext.Set<TEntity>().AsQueryable();
        if (!includes.IsNullOrEmpty())
        {
            foreach (var include in includes)
            {
                queryable = queryable.Include($"{include}");
            }
        }

        return await queryable.FirstOrDefaultAsync(x => x.Id == entityId);
    }

    public void Update(TEntity updatedEntity)
    {
        _dbContext.Set<TEntity>().Attach(updatedEntity);
        _dbContext.Entry(updatedEntity).State = EntityState.Modified;
    }

    public void Create(TEntity entity)
    {
        _dbContext.Set<TEntity>().Add(entity);
    }

    public async Task DeleteAsync(Guid entityId)
    {
        var entity = await _dbContext.Set<TEntity>().FindAsync(entityId);

        if (entity is null)
        {
            throw new ArgumentException($"Entity with '{entityId}' does not exists");
        }

        _dbContext.Set<TEntity>().Remove(entity);
    }

    public async Task<IEnumerable<TEntity>> GetAllAsync()
    {
        return await _dbContext.Set<TEntity>()
            .ToListAsync();
    }
}