﻿using System.Threading.Tasks;
using ZooDAL;
using ZooDAL.Models;

namespace ZooInfrastructure;

public sealed class UnitOfWork : IUnitOfWork
{
    private readonly ZooContext _dbContext;

    public UnitOfWork(
        ZooContext context,
        IRepository<Animal> animalRepository,
        IRepository<Enclosure> enclosureRepository,
        IRepository<Adoption> adoptionRepository,
        IRepository<Adopter> adopterRepository)
    {
        _dbContext = context;
        AnimalRepository = animalRepository;
        EnclosureRepository = enclosureRepository;
        AdoptionRepository = adoptionRepository;
        AdopterRepository = adopterRepository;
        ;
    }

    public IRepository<Enclosure> EnclosureRepository { get; }

    public IRepository<Adoption> AdoptionRepository { get; }

    public IRepository<Adopter> AdopterRepository { get; }

    public IRepository<Animal> AnimalRepository { get; }

    public async Task CommitAsync()
    {
        await _dbContext.SaveChangesAsync();
    }

    public void Dispose()
    {
        _dbContext.Dispose();
    }
}