﻿using Autofac;
using Microsoft.EntityFrameworkCore;
using ZooBL.Configs;
using ZooDAL;
using ZooDAL.Models;

namespace ZooTests;

public class Helper
{
    public async Task InsertIntoDbAsync<T>(T entity)
        where T : class
    {
        var context = AutofacBLConfig.Configure().Resolve<ZooContext>();
        var dbSet = context.Set<T>();
        dbSet.Add(entity);

        await context.SaveChangesAsync();
    }

    public async Task<T?> GetEntityByIdAsync<T>(Guid id)
        where T : BaseEntity
    {
        var context = AutofacBLConfig.Configure().Resolve<ZooContext>();
        var dbSet = context.Set<T>();
        return await dbSet.FirstOrDefaultAsync(x => x.Id == id);
    }

    public async Task<T?> GetEntityByIdWithIncludesAsync<T>(Guid id, params string[] includes)
        where T : BaseEntity
    {
        var context = AutofacBLConfig.Configure().Resolve<ZooContext>();
        var queryable = context.Set<T>().AsQueryable();
        foreach (var include in includes)
        {
            queryable = queryable.Include($"{include}");
        }

        return await queryable.FirstOrDefaultAsync(x => x.Id == id);
    }
}